searchData={"items":[{"type":"module","title":"Boltx","doc":"Bolt driver for Elixir.","ref":"Boltx.html"},{"type":"function","title":"Boltx.query/4","doc":"","ref":"Boltx.html#query/4"},{"type":"function","title":"Boltx.query!/4","doc":"","ref":"Boltx.html#query!/4"},{"type":"function","title":"Boltx.query_many/4","doc":"","ref":"Boltx.html#query_many/4"},{"type":"function","title":"Boltx.query_many!/4","doc":"","ref":"Boltx.html#query_many!/4"},{"type":"function","title":"Boltx.rollback/2","doc":"","ref":"Boltx.html#rollback/2"},{"type":"function","title":"Boltx.start_link/1","doc":"Starts the connection process and connects to a Bolt/Neo4j server.","ref":"Boltx.html#start_link/1"},{"type":"function","title":"Options - Boltx.start_link/1","doc":"* `:uri` - Connection URI. The uri configuration takes priority over the hostname, port, and scheme options.\n URI has the form: ` :// [: [?policy= ]]`\n\n* `:hostname` - Server hostname (default: `BOLT_HOST` env variable, then `\"localhost\"`)\n\n* `:port` - Server port (default: `BOLT_TCP_PORT` env variable, then `7687`)\n\n* `:scheme` - Is one among neo4j, neo4j+s, neo4j+ssc, bolt, bolt+s, bolt+ssc.\n\n* `:versions` - List of bolt versions you want to be negotiated with the server.\n\n* `:auth` - The basic authentication scheme\n\n* `:user_agent` - Optionally override the default user agent name. (Default: 'boltx/ ')\n\n* `:notifications_minimum_severity` - Set the minimum severity for notifications the server\n should send to the client. Disabling severities allows the server to skip analysis for those,\nwhich can speed up query execution. (default: nil) _New in neo4j v5.7 and Bolt v5.2_\n\n* `:notifications_disabled_categories` - Set categories of notifications the server should not\n send to the client. Disabling categories allows the server to skip analysis for those, which\ncan speed up query execution. (default: nil) _New in neo4j v5.7 and Bolt v5.2_\n\n* `:connect_timeout` - Socket connect timeout in milliseconds (default:\n    `15_000`)\n\nThe given options are passed down to DBConnection, some of the most commonly used ones are\n documented below:\n\n* `:after_connect` - A function to run after the connection has been established, either a\n    1-arity fun, a `{module, function, args}` tuple, or `nil` (default: `nil`)\n\n* `:pool` - The pool module to use, defaults to built-in pool provided by DBconnection\n\n * `:pool_size` - The size of the pool","ref":"Boltx.html#start_link/1-options"},{"type":"function","title":"Boltx.transaction/4","doc":"","ref":"Boltx.html#transaction/4"},{"type":"type","title":"Boltx.basic_auth/0","doc":"The basic authentication scheme relies on traditional username and password\n\n* `:username` - Username (default: `BOLT_USER` env variable)\n\n* `:password` - Password (default: `BOLT_PWD` env variable, then `nil`)","ref":"Boltx.html#t:basic_auth/0"},{"type":"type","title":"Boltx.conn/0","doc":"","ref":"Boltx.html#t:conn/0"},{"type":"type","title":"Boltx.option/0","doc":"","ref":"Boltx.html#t:option/0"},{"type":"type","title":"Boltx.start_option/0","doc":"","ref":"Boltx.html#t:start_option/0"},{"type":"module","title":"Boltx.Queries","doc":"","ref":"Boltx.Queries.html"},{"type":"module","title":"Boltx.Response","doc":"","ref":"Boltx.Response.html"},{"type":"function","title":"Boltx.Response.first/1","doc":"","ref":"Boltx.Response.html#first/1"},{"type":"function","title":"Boltx.Response.new/1","doc":"","ref":"Boltx.Response.html#new/1"},{"type":"type","title":"Boltx.Response.acc/0","doc":"","ref":"Boltx.Response.html#t:acc/0"},{"type":"type","title":"Boltx.Response.element/0","doc":"","ref":"Boltx.Response.html#t:element/0"},{"type":"type","title":"Boltx.Response.key/0","doc":"","ref":"Boltx.Response.html#t:key/0"},{"type":"type","title":"Boltx.Response.t/0","doc":"","ref":"Boltx.Response.html#t:t/0"},{"type":"type","title":"Boltx.Response.value/0","doc":"","ref":"Boltx.Response.html#t:value/0"},{"type":"module","title":"Boltx.ResponseEncoder","doc":"This module provides functions to encode a query result or data containing Boltx.Types\ninto various format.\n\nFor now, only JSON is supported.\n\nEncoding is  handled by protocols to allow override if a  specific implemention is required.\nSee targeted protocol documentation for more information","ref":"Boltx.ResponseEncoder.html"},{"type":"function","title":"Boltx.ResponseEncoder.encode/2","doc":"Encode the data in json format.\n\nThis is done is 2 steps:\n- first, the data is converted into a jsonable format\n- the result is encoded in json via Jason\n\nBoth of these steps are overridable, see:\n- for step 1: `Boltx.ResponseEncoder.Json`\n- for step 2 (depending of your preferred library):\n- `Boltx.ResponseEncoder.Json.Jason`\n- `Boltx.ResponseEncoder.Json.Poison`","ref":"Boltx.ResponseEncoder.html#encode/2"},{"type":"function","title":"Example - Boltx.ResponseEncoder.encode/2","doc":"iex> data = %{\"t1\" => %Boltx.Types.Node{\n    ...>     id: 69,\n    ...>     labels: [\"Test\"],\n    ...>     properties: %{\n    ...>       \"created\" => %Boltx.Types.DateTimeWithTZOffset{\n    ...>         naive_datetime: ~N[2016-05-24 13:26:08.543],\n    ...>         timezone_offset: 7200\n    ...>       },\n    ...>       \"uuid\" => 12345\n    ...>     }\n    ...>   }\n    ...> }\n    iex> Boltx.ResponseEncoder.encode(data, :json)\n    {:ok, ~S|{\"t1\":{\"id\":69,\"labels\":[\"Test\"],\"properties\":{\"created\":\"2016-05-24T13:26:08.543+02:00\",\"uuid\":12345}}}|}\n\n    iex> Boltx.ResponseEncoder.encode(\"\\xFF\", :json)\n    {:error, %Jason.EncodeError{message: \"invalid byte 0xFF in  >\"}}","ref":"Boltx.ResponseEncoder.html#encode/2-example"},{"type":"function","title":"Boltx.ResponseEncoder.encode!/2","doc":"Encode the data in json format.\n\nSimilar to `encode/1` except it will unwrap the error tuple and raise in case of errors.","ref":"Boltx.ResponseEncoder.html#encode!/2"},{"type":"function","title":"Example - Boltx.ResponseEncoder.encode!/2","doc":"iex> data = %{\"t1\" => %Boltx.Types.Node{\n    ...>     id: 69,\n    ...>     labels: [\"Test\"],\n    ...>     properties: %{\n    ...>       \"created\" => %Boltx.Types.DateTimeWithTZOffset{\n    ...>         naive_datetime: ~N[2016-05-24 13:26:08.543],\n    ...>         timezone_offset: 7200\n    ...>       },\n    ...>       \"uuid\" => 12345\n    ...>     }\n    ...>   }\n    ...> }\n    iex> Boltx.ResponseEncoder.encode!(data, :json)\n    ~S|{\"t1\":{\"id\":69,\"labels\":[\"Test\"],\"properties\":{\"created\":\"2016-05-24T13:26:08.543+02:00\",\"uuid\":12345}}}|\n\n    iex> Boltx.ResponseEncoder.encode!(\"\\xFF\", :json)\n    ** (Jason.EncodeError) invalid byte 0xFF in  >","ref":"Boltx.ResponseEncoder.html#encode!/2-example"},{"type":"protocol","title":"Boltx.ResponseEncoder.Json","doc":"Protocol controlling how a value is made jsonable.\n\nIts only purpose is to convert Bolt Boltx specific structures into elixir buit-in types\nwhich can be encoed in json by Jason.","ref":"Boltx.ResponseEncoder.Json.html"},{"type":"protocol","title":"Deriving - Boltx.ResponseEncoder.Json","doc":"If the provided default implementation don't fit your need, you can override with your own\nimplementation.\n\n#","ref":"Boltx.ResponseEncoder.Json.html#module-deriving"},{"type":"protocol","title":"Example - Boltx.ResponseEncoder.Json","doc":"Let's assume that you don't want Node's id available as they are Neo4j's ones and are not\nreliable because of id reuse and you want to have you own `uuid` in place.\nInstead of:\n```\n  {\n    id: 0,\n    labels: [\"TestNode\"],\n    properties: {\n      uuid: \"837806a7-6c37-4630-9f6c-9aa7ad0129ed\"\n      value: \"my node\"\n    }\n  }\n```\nyou want:\n```\n  {\n    uuid: \"837806a7-6c37-4630-9f6c-9aa7ad0129ed\",\n    labels: [\"TestNode\"],\n    properties: {\n      value: \"my node\"\n    }\n  }\n```\n\nYou can achieve that with the following implementation:\n```\ndefimpl Boltx.ResponseEncoder.Json, for: Boltx.Types.Node do\n  def encode(node) do\n    new_props = Map.drop(node.properties, :uuid)\n\n    node\n    |> Map.from_struct()\n    |> Map.put(:uuid, node.properties.uuid)\n    |> Map.put(:properties, new_props)\n  end\nend\n```\n\nIt is also possible to provide implementation that returns structs or updated Boltx.Types,\nthe use of a final `Boltx.ResponseEncoder.Json.encode()` will ensure that these values will\nbe converted to jsonable ones.","ref":"Boltx.ResponseEncoder.Json.html#module-example"},{"type":"function","title":"Boltx.ResponseEncoder.Json.encode/1","doc":"Convert a value in a jsonable format","ref":"Boltx.ResponseEncoder.Json.html#encode/1"},{"type":"type","title":"Boltx.ResponseEncoder.Json.t/0","doc":"All the types that implement this protocol.","ref":"Boltx.ResponseEncoder.Json.html#t:t/0"},{"type":"module","title":"Boltx.ResponseEncoder.Json.Jason","doc":"A default implementation for Jason encoding library.\n\nMore info about Jason: [https://hex.pm/packages/jason](https://hex.pm/packages/jason)\n\nAllow this usage:\n```\nconn = Boltx.conn()\n{:ok, res} = Boltx.query(conn, \"MATCH (t:TestNode) RETURN t\")\nJason.encode!(res)\n```\n\nDefault implementation can be overriden by providing your own implementation.\n\nMore info about implementation: [https://hexdocs.pm/jason/readme.html#differences-to-poison](https://hexdocs.pm/jason/readme.html#differences-to-poison)\n\n##","ref":"Boltx.ResponseEncoder.Json.Jason.html"},{"type":"module","title":"Note: - Boltx.ResponseEncoder.Json.Jason","doc":"In order to benefit from Boltx.ResponseEncoder implementation, use\n`Boltx.ResponseEncoder.Json.encode` and pass the result to the Jason\nencoding functions.","ref":"Boltx.ResponseEncoder.Json.Jason.html#module-note"},{"type":"module","title":"Boltx.ResponseEncoder.Json.Poison","doc":"A default implementation for Poison encoding library.\nMore info about poison here: [https://hex.pm/packages/poison](https://hex.pm/packages/poison)\n\nAllow this usage:\n```\nconn = Boltx.conn()\n{:ok, res} = Boltx.query(conn, \"MATCH (t:TestNode) RETURN t\")\nPoison.encode!(res)\n```\n\nDefault implementation can be overriden by providing your own implementation.\n\nMore info about implementation: [https://hexdocs.pm/poison/Poison.html#module-encoder](https://hexdocs.pm/poison/Poison.html#module-encoder)\n\n##","ref":"Boltx.ResponseEncoder.Json.Poison.html"},{"type":"module","title":"Note: - Boltx.ResponseEncoder.Json.Poison","doc":"In order to benefit from Boltx.ResponseEncoder implementation, use\n`Boltx.ResponseEncoder.Json.encode` and pass the result to the Poison\nencoding functions.","ref":"Boltx.ResponseEncoder.Json.Poison.html#module-note"},{"type":"module","title":"Boltx.Types","doc":"Basic support for representing nodes, relationships and paths belonging to\na Neo4j graph database.\n\nFour supported types of entities:\n\n- Node\n- Relationship\n- UnboundRelationship\n- Path\n\nMore details, about the Bolt protocol, here:\nhttps://github.com/boltprotocol/boltprotocol/blob/master/README.md\n\nAdditionally, since bolt V2, new types appears: spatial and temporal\nThose are not documented in bolt protocol, but neo4j documentation can be found here:\nhttps://neo4j.com/docs/cypher-manual/current/syntax/temporal/\nhttps://neo4j.com/docs/cypher-manual/current/syntax/spatial/\n\nTo work with temporal types, the following Elixir structs are available:\n- Time, DateTime, NaiveDateTime\n- Calendar.DateTime to work with timezone (as string)\n- TimeWithTZOffset, DateTimeWithTZOffset to work with (date)time and timezone offset(as integer)\n- Duration\n\nFor spatial types, you only need Point struct as it covers:\n- 2D point (cartesian or geographic)\n- 3D point (cartesian or geographic)","ref":"Boltx.Types.html"},{"type":"module","title":"Boltx.Types.DateTimeWithTZOffset","doc":"Manage a Time and its time zone offset.\n\nThis temporal types hs been added in bolt v2","ref":"Boltx.Types.DateTimeWithTZOffset.html"},{"type":"function","title":"Boltx.Types.DateTimeWithTZOffset.create/2","doc":"Create a valid DateTimeWithTZOffset from a NaiveDateTime and offset in seconds","ref":"Boltx.Types.DateTimeWithTZOffset.html#create/2"},{"type":"function","title":"Boltx.Types.DateTimeWithTZOffset.format_param/1","doc":"Convert DateTimeWithTZOffset struct in a cypher-compliant  string","ref":"Boltx.Types.DateTimeWithTZOffset.html#format_param/1"},{"type":"type","title":"Boltx.Types.DateTimeWithTZOffset.t/0","doc":"","ref":"Boltx.Types.DateTimeWithTZOffset.html#t:t/0"},{"type":"module","title":"Boltx.Types.Duration","doc":"a Duration type, as introduced in bolt V2.\n\nComposed of months, days, seconds and nanoseconds, it can be used in date operations","ref":"Boltx.Types.Duration.html"},{"type":"function","title":"Boltx.Types.Duration.create/4","doc":"Create a Duration struct from data returned by Neo4j.\n\nNeo4j returns a list of 4 integers:\n  - months\n  - days\n  - seconds\n  - nanoseconds\n\nStruct elements are computed in a logical way, then for exmple 65 seconds is 1min and 5\nseconds. Beware that you may not retrieve the same data you send!\nNote: days are not touched as they are not a fixed number of days for each month.","ref":"Boltx.Types.Duration.html#create/4"},{"type":"function","title":"Example: - Boltx.Types.Duration.create/4","doc":"iex> Duration.create(15, 53, 125, 54)\n    %Boltx.Types.Duration{\n      days: 53,\n      hours: 0,\n      minutes: 2,\n      months: 3,\n      nanoseconds: 54,\n      seconds: 5,\n      weeks: 0,\n      years: 1\n    }","ref":"Boltx.Types.Duration.html#create/4-example"},{"type":"function","title":"Boltx.Types.Duration.format_param/1","doc":"Convert a %Duration in a cypher-compliant string.\nTo know everything about duration format, please see:\nhttps://neo4j.com/docs/cypher-manual/current/syntax/temporal/#cypher-temporal-durations","ref":"Boltx.Types.Duration.html#format_param/1"},{"type":"type","title":"Boltx.Types.Duration.t/0","doc":"","ref":"Boltx.Types.Duration.html#t:t/0"},{"type":"module","title":"Boltx.Types.Entity","doc":"base structure for Node and Relationship","ref":"Boltx.Types.Entity.html"},{"type":"module","title":"Boltx.Types.Node","doc":"Self-contained graph node.\n\n  A Node represents a node from a Neo4j graph and consists of a\n  unique identifier (within the scope of its origin graph), a list of\n  labels and a map of properties.\n\n  https://github.com/boltprotocol/boltprotocol/blob/master/v1/_serialization.asciidoc#node","ref":"Boltx.Types.Node.html"},{"type":"type","title":"Boltx.Types.Node.t/0","doc":"","ref":"Boltx.Types.Node.html#t:t/0"},{"type":"module","title":"Boltx.Types.Path","doc":"Self-contained graph path.\n\n  A Path is a sequence of alternating nodes and relationships corresponding to a\n  walk in the graph. The path always begins and ends with a node.\n  Its representation consists of a list of distinct nodes,\n  a list of distinct relationships and a sequence of integers describing the\n  path traversal\n\n  https://github.com/boltprotocol/boltprotocol/blob/master/v1/_serialization.asciidoc#path","ref":"Boltx.Types.Path.html"},{"type":"function","title":"Boltx.Types.Path.graph/1","doc":"represents a traversal or walk through a graph and maintains a direction\nseparate from that of any relationships traversed","ref":"Boltx.Types.Path.html#graph/1"},{"type":"type","title":"Boltx.Types.Path.t/0","doc":"","ref":"Boltx.Types.Path.html#t:t/0"},{"type":"module","title":"Boltx.Types.Point","doc":"Manage spatial data introduced in Bolt V2\n\nPoint can be:\n  - Cartesian 2D\n  - Geographic 2D\n  - Cartesian 3D\n  - Geographic 3D","ref":"Boltx.Types.Point.html"},{"type":"function","title":"Boltx.Types.Point.create/3","doc":"A 2D point either needs:\n- 2 coordinates and a atom (:cartesian or :wgs_84) to define its type\n- 2 coordinates and a srid (4326 or 7203) to define its type","ref":"Boltx.Types.Point.html#create/3"},{"type":"function","title":"Examples: - Boltx.Types.Point.create/3","doc":"iex> Point.create(:cartesian, 10, 20.0)\n    %Boltx.Types.Point{\n      crs: \"cartesian\",\n      height: nil,\n      latitude: nil,\n      longitude: nil,\n      srid: 7203,\n      x: 10.0,\n      y: 20.0,\n      z: nil\n    }\n    iex> Point.create(4326, 10, 20.0)\n    %Boltx.Types.Point{\n      crs: \"wgs-84\",\n      height: nil,\n      latitude: 20.0,\n      longitude: 10.0,\n      srid: 4326,\n      x: 10.0,\n      y: 20.0,\n      z: 30.0\n    }","ref":"Boltx.Types.Point.html#create/3-examples"},{"type":"function","title":"Boltx.Types.Point.create/4","doc":"Create a 3D point\n\nA 3D point either needs:\n- 3 coordinates and a atom (:cartesian or :wgs_84) to define its type\n- 3 coordinates and a srid (4979 or 9147) to define its type","ref":"Boltx.Types.Point.html#create/4"},{"type":"function","title":"Examples: - Boltx.Types.Point.create/4","doc":"iex> Point.create(:cartesian, 10, 20.0, 30)\n    %Boltx.Types.Point{\n      crs: \"cartesian-3d\",\n      height: nil,\n      latitude: nil,\n      longitude: nil,\n      srid: 9157,\n      x: 10.0,\n      y: 20.0,\n      z: 30.0\n    }\n    iex> Point.create(4979, 10, 20.0, 30)\n    %Boltx.Types.Point{\n      crs: \"wgs-84-3d\",\n      height: 30.0,\n      latitude: 20.0,\n      longitude: 10.0,\n      srid: 4979,\n      x: 10.0,\n      y: 20.0,\n      z: 30.0\n    }","ref":"Boltx.Types.Point.html#create/4-examples"},{"type":"function","title":"Boltx.Types.Point.format_param/1","doc":"Convert a Point struct into a cypher-compliant map","ref":"Boltx.Types.Point.html#format_param/1"},{"type":"function","title":"Example - Boltx.Types.Point.format_param/1","doc":"iex(8)> Point.create(4326, 10, 20.0) |> Point.format_to_param\n    %{crs: \"wgs-84\", latitude: 20.0, longitude: 10.0, x: 10.0, y: 20.0}","ref":"Boltx.Types.Point.html#format_param/1-example"},{"type":"type","title":"Boltx.Types.Point.t/0","doc":"","ref":"Boltx.Types.Point.html#t:t/0"},{"type":"module","title":"Boltx.Types.Relationship","doc":"Self-contained graph relationship.\n\n  A Relationship represents a relationship from a Neo4j graph and consists of\n  a unique identifier (within the scope of its origin graph), identifiers\n  for the start and end nodes of that relationship, a type and a map of properties.\n\n  https://github.com/boltprotocol/boltprotocol/blob/master/v1/_serialization.asciidoc#relationship","ref":"Boltx.Types.Relationship.html"},{"type":"type","title":"Boltx.Types.Relationship.t/0","doc":"","ref":"Boltx.Types.Relationship.html#t:t/0"},{"type":"module","title":"Boltx.Types.TimeWithTZOffset","doc":"Manage a Time and its time zone offset.\n\nThis temporal types hs been added in bolt v2","ref":"Boltx.Types.TimeWithTZOffset.html"},{"type":"function","title":"Boltx.Types.TimeWithTZOffset.create/2","doc":"Create a valid TimeWithTZOffset from a Time and offset in seconds","ref":"Boltx.Types.TimeWithTZOffset.html#create/2"},{"type":"function","title":"Boltx.Types.TimeWithTZOffset.format_param/1","doc":"Convert TimeWithTZOffset struct in a cypher-compliant  string","ref":"Boltx.Types.TimeWithTZOffset.html#format_param/1"},{"type":"type","title":"Boltx.Types.TimeWithTZOffset.t/0","doc":"","ref":"Boltx.Types.TimeWithTZOffset.html#t:t/0"},{"type":"module","title":"Boltx.Types.UnboundRelationship","doc":"Self-contained graph relationship without endpoints.\n  An UnboundRelationship represents a relationship relative to a\n  separately known start point and end point.\n\n  https://github.com/boltprotocol/boltprotocol/blob/master/v1/_serialization.asciidoc#unboundrelationship","ref":"Boltx.Types.UnboundRelationship.html"},{"type":"type","title":"Boltx.Types.UnboundRelationship.t/0","doc":"","ref":"Boltx.Types.UnboundRelationship.html#t:t/0"},{"type":"extras","title":"Boltx","doc":"# Boltx\n\n`Boltx` is an Elixir driver for [Neo4j](https://neo4j.com/developer/graph-database/)/Bolt Protocol.\n\n- Supports Neo4j versions: 3.0.x/3.1.x/3.2.x/3.4.x/3.5.x/4.x/5.9 -5.13.0\n- Supports Bolt version: 1.0/2.0/3.0/4.x/5.0/5.1/5.2/5.3/5.4\n- Supports transactions, prepared queries, streaming, pooling and more via DBConnection\n- Automatic decoding and encoding of Elixir values\n\nDocumentation: [https://hexdocs.pm/boltx](https://hexdocs.pm/boltx)","ref":"readme.html"},{"type":"extras","title":"Features - Boltx","doc":"| Feature               | Implemented |\n| --------------------- | ------------ |\n| Querys                | YES          |\n| Transactions          | YES          |\n| Multi tenancy         | NO           |\n| Stream capabilities   | NO           |\n| Routing               | NO           |\n\n#","ref":"readme.html#features"},{"type":"extras","title":"Usage - Boltx","doc":"Add :boltx to your dependencies:\n\n```elixir\ndef deps() do\n  [\n    {:boltx, \"~> 0.0.2\"}\n  ]\nend\n```\n\nUsing the latest version.\n\n```elixir\n\nopts = [\n    hostname: \"127.0.0.1\",\n    auth: [username: \"neo4j\", password: \"\"],\n    user_agent: \"boltxTest/1\",\n    pool_size: 15,\n    max_overflow: 3,\n    prefix: :default\n]\n\niex> {:ok, conn} = Boltx.start_link(opts)\n{:ok, #PID }\n\niex> Boltx.query!(conn, \"return 1 as n\") |> Boltx.Response.first()\n%{\"n\" => 1}\n\n# Commit is performed automatically if everythings went fine\nBoltx.transaction(conn, fn conn ->\n  result = Boltx.query!(conn, \"CREATE (m:Movie {title: \"Matrix\"}) RETURN m\")\nend)\n\n```","ref":"readme.html#usage"},{"type":"extras","title":"Bolt Protocol message - Boltx","doc":"| Message       | Bolt Version                            | Implemented |\n| ------------- | --------------------------------------- | ----------- |\n| INIT          | V1, V2                                  | YES         |\n| HELLO         | V3, V4.x, v5.1, v5.2, v5.3, v5.4        | YES         |\n| LOGON         | V3, V4.x, v5.1, v5.2, v5.3, v5.4        | YES         |\n| RUN           | V1, V2, V3, V4.x, v5.1, v5.2, v5.3, v5.4| YES         |\n| PULL          | V1, V2, V3, V4.x, v5.1, v5.2, v5.3, v5.4| YES         |\n| BEGIN         | V1, V2, V3, V4.x, v5.1, v5.2, v5.3, v5.4| YES         |\n| COMMIT        | V1, V2, V3, V4.x, v5.1, v5.2, v5.3, v5.4| YES         |\n| ROLLBACK      | V1, V2, V3, V4.x, v5.1, v5.2, v5.3, v5.4| YES         |\n| LOGOFF        | V3, V4.x, v5.1, v5.2, v5.3, v5.4        | YES         |\n| TELEMETRY     | V5.4                                    | NO          |\n| GOODBYE       | V3, V4.x, v5.1, v5.2, v5.3, v5.4        | YES         |\n| RESET         | V3, V4.x, v5.1, v5.2, v5.3, v5.4        | YES         |\n| DISCARD       | V1, V2, V3, V4.x, v5.1, v5.2, v5.3, v5.4| YES         |\n| ROUTE         | V4.x, v5.1, v5.2, v5.3, v5.4            | NO          |\n| ACK_FAILURE   | V1, V2                                  | YES         |","ref":"readme.html#bolt-protocol-message"}],"content_type":"text/markdown"}